@@ -24,12 +24,12 @@ test_that("Scalar [*, sigmoid]",
   b <- parm(4, name = "b")
 
   # Create test expression
-  c <- cg.sigmoid(a) * cg.sigmoid(b)
+  c <- cg_sigmoid(a) * cg_sigmoid(b)
 
   # Calculate gradients
   grads <- gradients(c, run(c))
 
   # Check gradients
-  expect_equivalent(grads$a, approx.grad(c, a), tolerance = 1e-4)
-  expect_equivalent(grads$b, approx.grad(c, b), tolerance = 1e-4)
+  expect_equivalent(grads$a, approx_grad(c, a), tolerance = 1e-4)
+  expect_equivalent(grads$b, approx_grad(c, b), tolerance = 1e-4)
 })
